extensions [r nw gradient matrix]
__includes ["networkMetrics.nls"]

globals
[
  total-pop
  total-pop-frac

  invade-d50

  n-habitats
  n-habitats-occ

  edges
  adjacency-matrix

  control-habitats

  population-size
  delta-n

 ;; r-seed-from-file?

]

breed [habitats habitat]
breed [arrows arrow]

habitats-own
[
  inds
  immig-inds

  ever-invaded?

  grow
  capacity
  z-grow
  z-capacity
  z-grow-capacity

  to-remove

  sorted-links   ;; this is a *LIST* not an agent set
  sorted-nhbs    ;; this is a *LIST* not an agent set

  cluster-coeff
  sum-link-lengths
  meanLinkLengths

  bc
  wcc
  sna-bc
  prop-bc
  cutpoint?
  c-rank

  exports
  ;;kill-n-habitat
]

links-own
[
  rel-length ;; this is simply length i over sum length (1 to j)
]

to setup
   clear-all

   if not specify-nl-seed? [ set nl-seed new-seed ]
   random-seed nl-seed

   if not specify-r-seed? and not r-seed-from-file?
     [ set r-seed new-seed]

   if r-seed-from-file?
     [ set r-seed read-seed behaviorspace-run-number ]

   set population-size []
   set delta-n 1e4

   if not r-seed-from-file?
   [ write-seed r-seed ]

   initialise-r

   print "r initialised"

    with-local-randomness
    [
     build-arena
     init-pop
     print "network constructed"
     network-stats
     print "network stats computed"

     print "population initialised"
]
   reset-ticks
end

to initialise-r


   r:put "r" r-seed
   r:eval("set.seed(r)")
   r:eval ".libPaths(c('C:/Users/gper020/Documents/R/win-library/3.2',.libPaths()))"

   r:eval "library(spatstat)"
   r:eval "library(spatgraphs)"
   r:eval "library(sna)"
   r:eval "library(igraph)"

   r:eval("source('J:/private/SourceCode/NetLogo/invasionNetworks/controlRank.R')")

end

to get-pp
  ;;ct

  r:put "n" nNodes

  let inside-tol false
  while [inside-tol = false]
  [
    if process = "CSR" [
      r:eval "pattern <- rpoispp(n / 1e4, win = owin(c(0,100),c(0,100)))" ]
    ;;r:eval "pattern <- runifpoint(n, win = owin(c(0,100),c(0,100)))" ]
    if process = "SSI" [
      r:eval "pattern <- rSSI(r = 5, n, win = owin(c(0,100),c(0,100)))"
    ]

    if process = "Thomas" [
      r:eval "pattern <- rThomas(kappa = 10 / 1e4, scale = 5, mu = (n / 10),  win = owin(c(0,100),c(0,100)))" ]

    let np r:get "npoints(pattern)"

    if np >= nNodes * (1 - node-tol) and np <= nNodes * (1 + node-tol) [set inside-tol true]
  ]

  let xc r:get "pattern$x"
  let yc r:get "pattern$y"

  (foreach xc yc
  [
    create-habitats 1 [
      set xcor ?1
      set ycor ?2
      set size 2
      set shape "circle"
      set color white
    ]
  ])

end

;; this gets the spatial network from the spatgraphs library in R (needs v 2.6.2 or earlier)
to get-sg

  ask links [die]
  r:put "sg.method" sg-method
  r:put "k" k

  ifelse k = 0
  [
    r:eval "sg <- spatgraph(pattern, sg.method)"
  ]
  [
    r:eval "sg <- spatgraph(pattern, sg.method, k)"
  ]

  r:eval("ig <- sg2igraph(sg, pattern)")

  set edges r:get "sg$edges"

  let id 1

  foreach edges
  [
   let ed ?
   if not is-list? ed [set ed (list ed) ]
   foreach ed
   [
      ask habitat (id - 1) [create-link-with habitat (? - 1)]   ;; turtles are zero-indexed with respect to who
   ]
   set id id + 1
  ]

end


to build-arena
  get-pp
  set n-habitats count habitats ;; ok to here

  get-sg

end

to network-stats

  ask habitats [
    set sum-link-lengths sum [link-length] of my-links
    set meanLinkLengths sum-link-lengths / count my-links
  ]
  build-sorted-link-list

  if any? arrows [nw:set-context habitats links]    ;; this means the arrows (a breed) are excluded from all nw analyses

  get-nw-stats


  ;; allocate the control locations based on the control-location? variable
  if control-location? = "random"
  [
     set control-habitats n-of n-to-kill habitats
  ]

  if control-location? = "least distance"
  [
     set control-habitats min-n-of n-to-kill habitats [meanLinkLengths]
  ]

  if control-location? = "best connected"
  [
     set control-habitats habitats with [c-rank]
  ]

  if control-location? = "high r"
  [
     set control-habitats max-n-of n-to-kill habitats [grow]
  ]

  if control-location? = "high k"
  [
     set control-habitats max-n-of n-to-kill habitats [capacity]
  ]

  if control-location? = "high r and high k"
  [
     set control-habitats max-n-of n-to-kill habitats [z-grow-capacity]
  ]

  highlight-control

  ask habitats [set size 1 + sna-bc / 200]
end



;; set up the population and the demographic variables in each node/habitat
to init-pop

  let t [who] of habitats
  let idx 0

  ask habitats
  [
      set grow random-lognormal grow-mean grow-sd
      set capacity round random-lognormal k-mean k-sd

      set inds 0
      set exports 0
      set ever-invaded? false
  ]

  let mean-r mean [grow] of habitats
  let mean-k mean [capacity] of habitats
  let sd-r standard-deviation [grow] of habitats
  let sd-k standard-deviation [capacity] of habitats

  ask habitats
  [
    ifelse sd-r = 0 [set z-grow 0] [set z-grow  (z-score grow mean-r sd-r)]
    ifelse sd-k = 0 [set z-capacity 0] [set z-capacity (z-score capacity mean-k sd-k)]
    set z-grow-capacity z-grow + z-capacity
  ]

  if locate-rule = "random"
  [
    ask n-of (n-habitats * init-occupied) habitats [
      set inds round (capacity * init-pop-fraction)
      set ever-invaded? true
    ]
  ]

  if locate-rule = "best habitat"
  [
    ask max-n-of (n-habitats * init-occupied) habitats [grow] [
      set inds round (capacity * init-pop-fraction)
      set ever-invaded? true
    ]
  ]

  if locate-rule = "most connected"
  [
    ask max-n-of (n-habitats * init-occupied) habitats [bc] [
      set inds round (capacity * init-pop-fraction)
      set ever-invaded? true
    ]
  ]


  set total-pop sum [inds] of habitats
  set total-pop-frac total-pop / (sum [capacity] of habitats)
  set n-habitats-occ count habitats with [inds > 0]
  set invade-d50 -1

  colour-habitats

  ask habitats [
    ifelse grow >= 0.0
    [ set shape "circle"]
    [ set shape "circle 2"]
  ]
end


to go
  step
  tick

  set delta-n 99999
  if ticks > 150 and stop-tolerance > 0
  [
    (r:putdataframe "pop" "p" population-size)
    r:eval "l.pop <- tail(pop$p, 10)"
    r:eval "d <- mean(abs(diff(l.pop)))"
    set delta-n r:get "d"
  ]

  if total-pop = 0 or delta-n < stop-tolerance or ticks > 250 [stop]
end


;; a single model step/tick/year
to step

  pop-grow

  if bkgd-dispersal-rate > 0 [ bkgd-dispersal]     ;; background dispersal
  local-disperse                                   ;; local dispersal (when pop sufficient)
  if ldd-rate > 0[ long-disperse ]                 ;; long distance dispersal
  remove-surplus                                   ;; density-dependent mortality

  if ticks > startControl and n-to-kill > 0 [control]   ;; control

  set total-pop sum [inds] of habitats
  set total-pop-frac total-pop / (sum [capacity] of habitats)

  set population-size lput total-pop population-size
  set n-habitats-occ count habitats with [inds > 0]
  set-d50

  colour-habitats

end

;; background dispersal between habitats
to bkgd-dispersal
  ask habitats with [inds > 0]
  [
    if any? link-neighbors
    [
      let move random-binomial inds bkgd-dispersal-rate
      ask one-of link-neighbors [set inds inds + move]
      set inds inds - move
    ]
  ]
end

to colour-habitats
  ask habitats
  [
      ifelse inds = 0
      [ set color grey ]
      [ set color gradient:scale [[0 0 255] [255 0 0]] inds 1 (capacity * 1.1)]
  ]
end

;; logistic population grwoth (discrete)
to pop-grow
  ask habitats
  [
    if pop-model? = "logistic" [
      let r grow
      let deltaN inds * r * ( 1 - (inds / capacity))

      if deltaN > 0 and deltaN < 1 [ifelse random-float 1 <= deltaN [set deltaN 1][set deltaN 0]]
      if deltaN > 1 [set deltaN round deltaN]

      set inds inds + (ceiling deltaN)
    ]  ;; approx discrete-time logistic

    if pop-model? = "exponential" [
      let deltaN inds * grow
      set inds inds +  (ceiling deltaN)
    ] ;; exponential
  ]
end

;; move organisms in habitats at/above carrying capacity
to local-disperse

  ask habitats with [inds > (capacity * move-threshold) and any? link-neighbors]              ;; so inds only move above some threshold
  [                                                                                           ;; and the habitat is linked

    let from-habitat self
    let surplus floor( (inds - (capacity * move-threshold)) * move-fraction)                  ;; number of organisms that will (try to) move (floor to be conservative)

    ;; n to be removed from the habitat (i.e. they attempted to disperse)
    set to-remove surplus

    let n-move-total n-values count link-neighbors [surplus]    ;; these are binomially allocated in select-habitats
    ;show n-move-total

    set n-move-total select-habitats surplus                    ;; how many inds try to go to each target
    ;show n-move-total                                          ;; ordered list with n to move to each of the sorted-nhbs

    let idx 0

    ;; allocate dispersers to each of the nhb patches (nodes)
    foreach sorted-nhbs
    [
      let target ?
      let n-to-target item idx n-move-total                     ;; no. of inds to move to the target (via select-habitats)

      if n-to-target > 0
      [
        let focal-link link [who] of from-habitat [who] of target

        ask target
        [
          ;; success of traverse = f(length) :: (1/d) ^ a
          let p-success ((1 / [link-length] of focal-link) ^ mortality-exponent)

          ;; update n-to-target against possible n that could move
          if n-to-target > (capacity - inds) [set n-to-target max (list 0 (capacity - inds))]
          let n-move-success random-binomial n-to-target p-success      ; some fraction p-success are successful

          if n-move-success > 0
          [
            set immig-inds immig-inds + n-move-success
            ask from-habitat [set exports exports + n-move-success]
            if ever-invaded? = false [set ever-invaded? true ]
          ]
        ]
      ]
      set idx idx + 1
    ]

    set inds inds - surplus
  ]

  ask habitats
  [
    set inds inds + immig-inds
    remove-surplus
    set immig-inds 0
  ]

end

to long-disperse

  if ldd-rate > 0
  [
    ;;  the per habitat prob of getting a LDD is ldd-rate * no. occup habitats
    let p-per-hab n-habitats-occ * ldd-rate

    ask habitats
    [
      if random-float 1 <= p-per-hab
      [
        ask one-of other habitats with [inds > 0] [set inds inds - 1]
        set inds inds + 1
      ]
    ]
  ]
end


to remove-surplus

  ;; remove organisms that have dispersed
  ask habitats [
    set inds inds - to-remove
    set to-remove 0
  ]

  ;; remove any excess over K (shouldn't occur)
  ask habitats with [inds > capacity]
  [
    set inds capacity
  ]

end

to-report global-clustering-coefficient
  let closed-triplets sum [ nw:clustering-coefficient * count my-links * (count my-links - 1) ] of habitats
  let triplets sum [ count my-links * (count my-links - 1) ] of habitats
  report closed-triplets / triplets
end

to-report ave-local-clustering
  report mean [ nw:clustering-coefficient ] of habitats
end

to-report prop-empty
  ifelse count habitats != 0
  [ report count habitats with [inds = 0] / count habitats ]
  [ report 0 ]

end

to-report prop-invaded
  ifelse count habitats != 0
  [ report count habitats with [ever-invaded?] / count habitats ]
  [ report 0 ]

end

to set-d50
  if invade-d50 = -1
  [
     if prop-invaded >= 0.5 [set invade-d50 ticks]
  ]
end


to-report random-binomial [sz pr]
  report length filter [?] n-values sz [random-float 1 < pr]
end

;; generate a lognormal deviate with specified mean and sd (takes *NON* log values)
to-report random-lognormal [m s]
  let x ln (1 + (s / m) ^ 2)
  let mu ln m - x / 2
  let sigma sqrt x
  report exp (mu + random-normal 0 1 * sigma)
end

;; This routine selects a new habitat to fly to based on the probability list.
to-report get-habitat-from-list [ propList tMoveToList]
    ; now select a tree from the prob list
    let destHabitat no-turtles

    let idx select-replacement-from-list propList
    set destHabitat item idx tMoveToList

    ;; return the new tree as destTree
    report destHabitat
end

to-report select-habitats [surp]
;; Select on basis of distance

  let numbers-to-move n-values (length sorted-links) [0]
  ;; n-move is a list of linked habitats

  ifelse any? link-neighbors
  [
    let propList []
    let lengthList []

    ;; habitat to move to inversely proportional to distance
    if disperse-rule = "prop to length"
    [
      foreach sorted-links [set lengthList lput ([link-length] of ?)  lengthList ]
      repeat surp
      [
        let idx weighted-random-idx lengthList                                                       ;; random link-nhb weighted by length
        set numbers-to-move replace-item idx numbers-to-move ((item idx numbers-to-move) + 1)        ;; add one to it
      ]
    ]

    ;; all connected habitats are equi-probable to be moved to
    if disperse-rule = "neutral"
    [
      repeat surp
      [
        let idx one-of n-values length sorted-links [?]    ;; strictly random link-nhb
        set numbers-to-move replace-item idx numbers-to-move ((item idx numbers-to-move) + 1)        ;; add one to it
      ]
    ]

  ]
  [
    ;; do nothing otherwise...
  ]
  report numbers-to-move

end

;; Control here is numbers based
to control

  ask control-habitats
  [
    set inds floor (inds - (inds * control-efficiency))
  ]
end


to build-sorted-link-list

  ask habitats
  [

     let nhb nobody
     let sn []
     set sorted-links reverse sort-on [link-length] my-links

     foreach sorted-links
     [
       ifelse [end1] of ? = self [set nhb [end2] of ?] [set nhb [end1] of ?]
       set sn lput nhb sn
     ]

     set sorted-nhbs sn
  ]
end

to-report make-list-cumulative [vec]
  report butfirst reverse reduce [fput (?2 + first ?1) ?1] fput [0] vec
end

;; Select an item from a problist ascending and cumulative
;; returns index number to extract
to-report select-replacement-from-list [probVec]

  let r random-float 1
  report position (first filter [r < ?] probVec) probVec

end

to-report scale-list [l]

  r:put "lx" l

  report r:get "scale(lx)"
end




to highlight-control

    if highlight-control?
    [
      ask control-habitats
      [
        hatch-arrows 1
        [
          ;;show target
          ;show min (list (world-width - 1.5) ([xcor] of target + 2))
          set xcor min (list (world-width - 2.5) (xcor + 1.5))
          set ycor max (list 0 (ycor + 0.5))
          set shape "arrow"
          set color green
          set size 3
          set heading 90
        ]
      ]
    ]

end


to-report read-seed [bn]
  let rfile seed-file
  file-open rfile
  repeat (bn - 1) [let x file-read-line]
  let r file-read
  file-close
  report r
end

to write-seed [r]
  let rfile seed-file
  file-open rfile
  file-print r
  file-close
end


to write-graph
  let gfile "graph.txt"

  if file-exists? gfile [file-delete gfile]

  file-open gfile

  file-print " x y md bc r k n d"
  ask habitats
  [
    file-write xcor file-write ycor file-write (sum-link-lengths / length sorted-links) file-write sna-bc file-write grow
    file-write capacity file-write inds file-write exports
    file-print ""
  ]

  file-close
end


to-report flux-correl
  (r:putagent "habitats" habitats "sna-bc" "exports")
;  ;; calculate correlation between weight and height
  r:eval "c <- cor(habitats$sna-bc, habitats$exports)"
  let c r:get "c"
  report c
end

to-report dist-correl
  (r:putagent "habitats" habitats "meanLinkLengths" "exports")
;  ;; calculate correlation between weight and height
  r:eval "c <- cor(habitats$meanLinkLengths, habitats$exports)"
  let c r:get "c"
  report c
end

to-report z-score [x m s]
  ;;show s
  report (x - m) / s
end

to-report weighted-random-idx [prob-list]

  let values n-values (length prob-list) [?]
  let cum-prob reduce [
    lput (?2 + (ifelse-value (empty? ?1) [0] [last ?1])) ?1
  ] (fput [] prob-list)

  ; Roll a uniform random number weighted by the cumulative probability vector
  let x random-float sum prob-list
  let j  -1
  let found false
  while [(not found) and (j < (length cum-prob))]
  [
    set j (j + 1)
    if (x <= item j cum-prob) [set found true]
  ]

  report item j values
end
@#$#@#$#@
GRAPHICS-WINDOW
210
10
624
445
-1
-1
4.0
1
10
1
1
1
0
0
0
1
0
100
0
100
1
1
1
ticks
13.0

SLIDER
25
63
197
96
nNodes
nNodes
10
250
100
5
1
NIL
HORIZONTAL

CHOOSER
37
138
175
183
process
process
"CSR" "SSI" "Thomas"
0

CHOOSER
35
190
173
235
sg-method
sg-method
"gabriel" "delaunay" "RNG" "MST" "knn" "geometric"
2

BUTTON
629
11
702
44
console
r:setPlotDevice\nr:interactiveShell
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

SLIDER
23
239
195
272
k
k
0
100
3
1
1
NIL
HORIZONTAL

MONITOR
630
58
738
103
Ave local clustering
ave-local-clustering
4
1
11

MONITOR
630
102
744
147
Global clustering
global-clustering-coefficient
4
1
11

BUTTON
7
317
70
350
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
31
279
181
301
Set k = 0 for gabriel, delaunay and MST
9
0.0
1

MONITOR
630
153
687
198
No links
count links
0
1
11

MONITOR
630
256
733
301
Pop (global) size
total-pop
0
1
11

PLOT
1060
175
1260
325
Pop size
NIL
NIL
0.0
10.0
0.0
10.0
true
false
"" ""
PENS
"default" 1.0 0 -16777216 true "" "plot total-pop"

BUTTON
146
317
209
350
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

PLOT
1059
22
1259
172
Local pop sizes
NIL
NIL
0.0
40.0
0.0
40.0
false
false
"set-histogram-num-bars 25" ""
PENS
"default" 1.0 1 -16777216 true "" "histogram [inds] of habitats"

MONITOR
631
208
719
253
max local pop
max [inds] of habitats
0
1
11

MONITOR
741
58
818
103
prop empty
prop-empty
3
1
11

MONITOR
745
103
832
148
global-quality
mean [grow] of habitats
4
1
11

PLOT
1061
329
1261
479
Prop unoccupied patches
NIL
NIL
0.0
10.0
0.0
1.0
true
true
"" ""
PENS
"emp" 1.0 0 -13345367 true "" "plot prop-empty"
"inv" 1.0 0 -2674135 true "" "plot prop-invaded"

MONITOR
722
209
792
254
saturation
sum [capacity] of habitats
0
1
11

SLIDER
631
355
806
388
bkgd-dispersal-rate
bkgd-dispersal-rate
0
1
0
.005
1
NIL
HORIZONTAL

SLIDER
20
364
192
397
init-occupied
init-occupied
.005
1
0.2
.005
1
NIL
HORIZONTAL

TEXTBOX
213
448
404
481
Filled circles have r > 0.0\nBlue <--> red indicates local population size\nSize indicates connectivity
9
0.0
1

BUTTON
77
318
140
351
step
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
35
41
185
61
This is a random variable so nNodes not guaranteed to be exactly this
8
0.0
1

MONITOR
694
153
790
198
No. of habitats
n-habitats
0
1
11

CHOOSER
630
305
768
350
disperse-rule
disperse-rule
"neutral" "prop to length"
0

CHOOSER
35
437
173
482
locate-rule
locate-rule
"random" "best habitat" "most connected"
0

SLIDER
19
400
191
433
init-pop-fraction
init-pop-fraction
0
1.0
1
.01
1
NIL
HORIZONTAL

CHOOSER
866
193
1006
238
control-location?
control-location?
"random" "least distance" "best connected" "high r" "high k" "high r and high k"
2

SWITCH
872
266
1007
299
highlight-cuts?
highlight-cuts?
1
1
-1000

SLIDER
450
448
622
481
grow-mean
grow-mean
0
0.2
0.2
.01
1
NIL
HORIZONTAL

SLIDER
449
483
621
516
grow-sd
grow-sd
0
.25
0
.005
1
NIL
HORIZONTAL

SLIDER
624
449
796
482
k-mean
k-mean
5
50
40
1
1
NIL
HORIZONTAL

SLIDER
625
483
797
516
k-sd
k-sd
0
100
0
1
1
NIL
HORIZONTAL

SLIDER
850
152
1022
185
control-efficiency
control-efficiency
0
1
0.9
.01
1
NIL
HORIZONTAL

CHOOSER
35
491
173
536
pop-model?
pop-model?
"exponential" "logistic"
1

SLIDER
632
393
807
426
move-threshold
move-threshold
0
1
0.3
.01
1
NIL
HORIZONTAL

SLIDER
814
393
986
426
mortality-exponent
mortality-exponent
0
5
0.5
.1
1
NIL
HORIZONTAL

SLIDER
811
354
983
387
move-fraction
move-fraction
0
1.0
0.3
.01
1
NIL
HORIZONTAL

SLIDER
849
28
1021
61
startControl
startControl
0
500
25
10
1
NIL
HORIZONTAL

SLIDER
848
63
1020
96
n-to-kill
n-to-kill
0
100
50
1
1
NIL
HORIZONTAL

SWITCH
870
305
1010
338
highlight-control?
highlight-control?
1
1
-1000

SLIDER
233
490
405
523
stop-tolerance
stop-tolerance
0
10
0
0.1
1
NIL
HORIZONTAL

SLIDER
475
553
647
586
r-seed
r-seed
-2147483648
2147483648
1103813775
1
1
NIL
HORIZONTAL

SWITCH
333
553
474
586
specify-r-seed?
specify-r-seed?
1
1
-1000

SLIDER
475
587
647
620
nl-seed
nl-seed
-2147483648
2147483648
-987539735
1
1
NIL
HORIZONTAL

SWITCH
333
587
474
620
specify-nl-seed?
specify-nl-seed?
1
1
-1000

SWITCH
659
568
807
601
r-seed-from-file?
r-seed-from-file?
0
1
-1000

MONITOR
738
257
795
302
TFP
total-pop-frac
3
1
11

MONITOR
800
258
857
303
TFI
prop-invaded
3
1
11

MONITOR
799
210
856
255
d50
invade-d50
0
1
11

SLIDER
24
99
196
132
node-tol
node-tol
0
.1
0
.005
1
NIL
HORIZONTAL

INPUTBOX
828
550
1061
610
seed-file
rseedPhaseZoom.txt
1
0
String

SLIDER
812
448
984
481
ldd-rate
ldd-rate
0
0.1
0
0.005
1
NIL
HORIZONTAL

@#$#@#$#@
## WHAT IS IT?

(a general understanding of what the model is trying to show or explain)

## HOW IT WORKS

(what rules the agents use to create the overall behavior of the model)

## HOW TO USE IT

(how to use the model, including a description of each of the items in the Interface tab)

## THINGS TO NOTICE

(suggested things for the user to notice while running the model)

## THINGS TO TRY

(suggested things for the user to try to do (move sliders, switches, etc.) with the model)

## EXTENDING THE MODEL

(suggested things to add or change in the Code tab to make the model more complicated, detailed, accurate, etc.)

## NETLOGO FEATURES

(interesting or unusual features of NetLogo that the model uses, particularly in the Code tab; or where workarounds were needed for missing features)

## RELATED MODELS

(models in the NetLogo Models Library and elsewhere which are of related interest)

## CREDITS AND REFERENCES

(a reference to the model's URL on the web if it has one, as well as any other necessary credits, citations, and links)
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
15
Circle -1 true true 203 65 88
Circle -1 true true 70 65 162
Circle -1 true true 150 105 120
Polygon -7500403 true false 218 120 240 165 255 165 278 120
Circle -7500403 true false 214 72 67
Rectangle -1 true true 164 223 179 298
Polygon -1 true true 45 285 30 285 30 240 15 195 45 210
Circle -1 true true 3 83 150
Rectangle -1 true true 65 221 80 296
Polygon -1 true true 195 285 210 285 210 240 240 210 195 210
Polygon -7500403 true false 276 85 285 105 302 99 294 83
Polygon -7500403 true false 219 85 210 105 193 99 201 83

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

wolf
false
0
Polygon -16777216 true false 253 133 245 131 245 133
Polygon -7500403 true true 2 194 13 197 30 191 38 193 38 205 20 226 20 257 27 265 38 266 40 260 31 253 31 230 60 206 68 198 75 209 66 228 65 243 82 261 84 268 100 267 103 261 77 239 79 231 100 207 98 196 119 201 143 202 160 195 166 210 172 213 173 238 167 251 160 248 154 265 169 264 178 247 186 240 198 260 200 271 217 271 219 262 207 258 195 230 192 198 210 184 227 164 242 144 259 145 284 151 277 141 293 140 299 134 297 127 273 119 270 105
Polygon -7500403 true true -1 195 14 180 36 166 40 153 53 140 82 131 134 133 159 126 188 115 227 108 236 102 238 98 268 86 269 92 281 87 269 103 269 113

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 5.3.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="scenario2-multigraphs-fromseed" repetitions="1000" runMetricsEveryStep="false">
    <setup>set r-seed-from-file? true
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="seed-file">
      <value value="&quot;rSeedS2.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startControl">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-to-kill">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario-1-same-graphs" repetitions="1000" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="r-seed-from-file?">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="specify-r-seed?">
      <value value="true"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="r-seed">
      <value value="-2364781"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startControl">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-to-kill">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="base-trajectory" repetitions="100" runMetricsEveryStep="true">
    <setup>set specify-r-seed? true
set r-seed 1956151578
set r-seed-from-file? false
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <enumeratedValueSet variable="startControl">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-to-kill">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario3-phase" repetitions="10" runMetricsEveryStep="false">
    <setup>set r-seed-from-file? true
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="startControl">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="init-occupied" first="0.1" step="0.1" last="1"/>
    <steppedValueSet variable="init-pop-fraction" first="0.1" step="0.1" last="1"/>
    <enumeratedValueSet variable="n-to-kill">
      <value value="5"/>
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ldd-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed-file">
      <value value="&quot;rseedPhase.txt&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario4-stochasticity-rev" repetitions="10" runMetricsEveryStep="false">
    <setup>set r-seed-from-file? true
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <metric>grow-sd</metric>
    <metric>k-sd</metric>
    <metric>min [grow] of habitats</metric>
    <metric>max [grow] of habitats</metric>
    <metric>min [capacity] of habitats</metric>
    <metric>max [capacity] of habitats</metric>
    <enumeratedValueSet variable="seed-file">
      <value value="&quot;rseedDemography.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
      <value value="&quot;high r&quot;"/>
      <value value="&quot;high k&quot;"/>
      <value value="&quot;high r and high k&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startControl">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-to-kill">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-mean">
      <value value="40"/>
    </enumeratedValueSet>
    <steppedValueSet variable="grow-sd" first="0" step="0.02" last="0.2"/>
    <steppedValueSet variable="k-sd" first="0" step="2" last="40"/>
  </experiment>
  <experiment name="scenario0-correlations" repetitions="10" runMetricsEveryStep="false">
    <setup>set highlight-control? false
set r-seed-from-file? false
set specify-r-seed? false
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>flux-correl</metric>
    <metric>dist-correl</metric>
    <enumeratedValueSet variable="startControl">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-to-kill">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0"/>
    </enumeratedValueSet>
    <steppedValueSet variable="init-occupied" first="0.05" step="0.05" last="1"/>
    <steppedValueSet variable="init-pop-fraction" first="0.05" step="0.05" last="1"/>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario3-phase-zoom" repetitions="10" runMetricsEveryStep="false">
    <setup>set r-seed-from-file? true
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="startControl">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
    <steppedValueSet variable="init-occupied" first="0.02" step="0.02" last="0.2"/>
    <steppedValueSet variable="init-pop-fraction" first="0.05" step="0.05" last="1"/>
    <enumeratedValueSet variable="n-to-kill">
      <value value="5"/>
      <value value="20"/>
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-sd">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-mean">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-sd">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ldd-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="seed-file">
      <value value="&quot;rseedPhaseZoom.txt&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario5-efficacy" repetitions="30" runMetricsEveryStep="false">
    <setup>set highlight-control? false
set r-seed-from-file? false
set specify-r-seed? false
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="startControl">
      <value value="25"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-to-kill" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario6-efficacyStochastic" repetitions="10" runMetricsEveryStep="false">
    <setup>set highlight-control? false
set r-seed-from-file? false
set specify-r-seed? false
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="startControl">
      <value value="50"/>
    </enumeratedValueSet>
    <steppedValueSet variable="n-to-kill" first="1" step="1" last="100"/>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-mean">
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="grow-sd">
      <value value="0.1"/>
      <value value="0.2"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-mean">
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="k-sd">
      <value value="20"/>
      <value value="40"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="bkgd-dispersal-rate">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-fraction">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="move-threshold">
      <value value="0.3"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
      <value value="&quot;high r&quot;"/>
    </enumeratedValueSet>
  </experiment>
  <experiment name="scenario2-multigraphs-fromseed-LDD" repetitions="1000" runMetricsEveryStep="false">
    <setup>set r-seed-from-file? true
setup</setup>
    <go>go</go>
    <timeLimit steps="300"/>
    <metric>r-seed</metric>
    <metric>total-pop</metric>
    <metric>total-pop-frac</metric>
    <metric>prop-empty</metric>
    <metric>prop-invaded</metric>
    <metric>invade-d50</metric>
    <enumeratedValueSet variable="seed-file">
      <value value="&quot;rseedLDD.txt&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="startControl">
      <value value="25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="n-to-kill">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-efficiency">
      <value value="0.9"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-occupied">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="init-pop-fraction">
      <value value="0.25"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-location?">
      <value value="&quot;random&quot;"/>
      <value value="&quot;least distance&quot;"/>
      <value value="&quot;best connected&quot;"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="ldd-rate">
      <value value="1.0E-4"/>
      <value value="5.0E-4"/>
      <value value="0.001"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
